
The following command is supposed to append command current line to the history:

```s
history -s "whatever command line"
```

However, when used in shell function invoked on completion (see `@/exe/shell_env.bash`),
it removes the last command in the history. Why?

Issue with the comment:
https://stackoverflow.com/questions/60286899/append-command-to-history-without-removing-last-command#comment137405926_60286899
